:mod:`art.classifiers.scikitlearn`
==================================
.. automodule:: art.classifiers.scikitlearn

Scikit-learn DecisionTreeClassifier Wrapper
-------------------------------------------
.. autoclass:: ScikitlearnDecisionTreeClassifier
   :members:
   :special-members:

Scikit-learn ExtraTreeClassifier Wrapper
----------------------------------------
.. autoclass:: ScikitlearnExtraTreeClassifier
   :members:
   :special-members:

Scikit-learn AdaBoostClassifier Wrapper
---------------------------------------
.. autoclass:: ScikitlearnAdaBoostClassifier
   :members:
   :special-members:

Scikit-learn BaggingClassifier Wrapper
--------------------------------------
.. autoclass:: ScikitlearnBaggingClassifier
   :members:
   :special-members:

Scikit-learn ExtraTreesClassifier Wrapper
-----------------------------------------
.. autoclass:: ScikitlearnExtraTreesClassifier
   :members:
   :special-members:

Scikit-learn GradientBoostingClassifier Wrapper
-----------------------------------------------
.. autoclass:: ScikitlearnGradientBoostingClassifier
   :members:
   :special-members:

Scikit-learn RandomForestClassifier Wrapper
-------------------------------------------
.. autoclass:: ScikitlearnRandomForestClassifier
   :members:
   :special-members:

Scikit-learn LogisticRegression Wrapper
---------------------------------------
.. autoclass:: ScikitlearnLogisticRegression
   :members:
   :special-members:

Scikit-learn SVC Wrapper
------------------------
.. autoclass:: ScikitlearnSVC
   :members:
   :special-members:

Base Class Scikit-learn
-----------------------
.. autoclass:: ScikitlearnClassifier
   :members:
